@@ -28,6 +28,7 @@ class AjaxFKWidget(TextInput):
     model = None
     related_field = None
     filter_dict = {}
+    hide_input = False
 
     window_url = None
     load_url = None
@@ -66,6 +67,8 @@ class AjaxFKWidget(TextInput):
                     self.model.__name__.lower(),
                     )
 
+        self.hide_input = kwargs.pop('hide_input', self.hide_input)
+
         super(AjaxFKWidget, self).__init__(*args, **kwargs)
 
     def get_from_rel(self):
@@ -81,7 +84,13 @@ class AjaxFKWidget(TextInput):
         attrs = attrs or {}
         attrs['class'] = attrs.get('class', '') + ' ajax-fk'
 
+        # Renders using inherited class
         ret = super(AjaxFKWidget, self).render(name, value, attrs)
+
+        # Buf, if is going to hide the input, then replace 'text' to 'hidden'
+        if self.hide_input:
+            ret = ret.replace(' type="text" ', ' type="hidden" ')
+
         class_path = '.'.join([self.model.__module__, self.model.__name__])
 
         display = self.make_display(attrs, value)
@@ -169,13 +178,43 @@ class AjaxFKDriver(object):
     search_fields = None
     list_filter = None
     ordering = None
+    template = 'djangoplus/ajaxfkwidget_window.html'
 
     def __init__(self, request, cls=None):
         self.request = request
         self.cls = cls
 
+    def _get_field_display(self, field_name):
+        if field_name == '__unicode__':
+            return self.model._meta.verbose_name.capitalize()
+
+        try:
+            return getattr(self, 'get_%s_display'%field_name)()
+        except AttributeError:
+            return self.model._meta.get_field_by_name(field_name)[0].verbose_name.capitalize()
+
+    def _get_field_value(self, field_name, obj):
+        # Unicode representation
+        if field_name == '__unicode__':
+            return unicode(obj)
+
+        # Using a specific method
+        try:
+            return getattr(self, 'get_%s_value'%field_name)(obj)
+        except AttributeError:
+            pass
+
+        # Getting by attribute
+        value = getattr(obj, field_name, None)
+
+        # If the attribute is callable
+        if callable(value):
+            value = value()
+
+        return value
+
     def get_columns(self):
-        return [self.model._meta.get_field_by_name(f)[0].verbose_name.capitalize() for f in self.list_display]
+        return [self._get_field_display(f) for f in self.list_display]
 
     def get_results(self):
         qs = self.get_query_set()
@@ -269,7 +308,7 @@ def window_view(request, app, model):
     function_get_url = driver.get_display_url
 
     return render_to_response(
-            'djangoplus/ajaxfkwidget_window.html',
+            driver.template,
             locals(),
             context_instance=RequestContext(request),
             )
